package lcsb.mapviewer.services.search;

import java.util.List;

import org.apache.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;

import lcsb.mapviewer.annotation.data.Target;
import lcsb.mapviewer.model.map.model.Model;
import lcsb.mapviewer.model.map.species.Element;
import lcsb.mapviewer.services.search.data.ElementIdentifier;
import lcsb.mapviewer.services.view.AnnotationViewFactory;

/**
 * Factory for {@link ISearchResultView search results}.
 * 
 * @author Piotr Gawron
 *
 * @param <T>
 *          type from which objects arec reated
 * @param <S>
 *          search ruslt type
 */
@Transactional(value = "txManager")
public abstract class SearchResultFactory<T, S extends ISearchResultView> extends ElementViewFactory<T, S> {

	/**
	 * Default class logger.
	 */
	@SuppressWarnings("unused")
	private final Logger logger = Logger.getLogger(SearchResultFactory.class);

	/**
	 * Creates list of object identifiers from search result.
	 * 
	 * @param object
	 *          search result from which elements should be extracted
	 * @param model
	 *          model on which search was performed
	 * @return list of lightweighted structures for given search result
	 */
	public abstract List<ElementIdentifier> searchResultToElementIdentifier(S object, Model model);

	/**
	 * Factory object used for creation of
	 * {@link lcsb.mapviewer.services.view.AnnotationView} elements.
	 */
	@Autowired
	private AnnotationViewFactory	annotationViewFactory;

	@Autowired
	private ElementMatcher				elementMatcher;

	protected boolean elementMatch(Target target, Element element) {
		return elementMatcher.elementMatch(target, element);
	}

	/**
	 * @return the annotationViewFactory
	 * @see #annotationViewFactory
	 */
	public AnnotationViewFactory getAnnotationViewFactory() {
		return annotationViewFactory;
	}

	/**
	 * @param annotationViewFactory
	 *          the annotationViewFactory to set
	 * @see #annotationViewFactory
	 */
	public void setAnnotationViewFactory(AnnotationViewFactory annotationViewFactory) {
		this.annotationViewFactory = annotationViewFactory;
	}

	/**
	 * @return the elementMatcher
	 * @see #elementMatcher
	 */
	public ElementMatcher getElementMatcher() {
		return elementMatcher;
	}

	/**
	 * @param elementMatcher
	 *          the elementMatcher to set
	 * @see #elementMatcher
	 */
	public void setElementMatcher(ElementMatcher elementMatcher) {
		this.elementMatcher = elementMatcher;
	}

}
