package lcsb.mapviewer.services.search.comment;

import java.awt.geom.Point2D;
import java.util.ArrayList;
import java.util.List;

import lcsb.mapviewer.common.Pair;
import lcsb.mapviewer.services.search.ISearchResultView;

/**
 * This class represent data that are sent into the client (by designe Google
 * Map object, but not necessery). It is connected to the comment on the map. It
 * contains information required for vizualization like localization
 * information. However, there are no information about formating, css, etc.
 * 
 * @author Piotr Gawron
 * 
 */
public class FullCommentView extends LightCommentView implements ISearchResultView {

	/**
	 * 
	 */
	private static final long					 serialVersionUID	= 1L;

	/**
	 * List of comments in the marker. {@link Pair#left} is id of a comment;
	 * {@link Pair#right} is a content.
	 */
	private List<Pair<String, String>> comments					= new ArrayList<Pair<String, String>>();

	/**
	 * Type of the object that is commented.
	 */
	private Class<?>									 type							= null;

	/**
	 * Default constructor.
	 * 
	 * @param point
	 *          {@link Point2D} where the comment is placed
	 * @param idModel
	 *          identifier of the model where comment is placed
	 * 
	 */
	public FullCommentView(Point2D point, Integer idModel) {
		super(point, idModel);
	}

	/**
	 * Default constructor.
	 * 
	 * @param objectId
	 *          identifier of the element that is commented
	 * @param idModel
	 *          identifier of the model where comment is placed
	 * 
	 */
	public FullCommentView(Integer objectId, Integer idModel) {
		super(objectId, idModel);
	}

	/**
	 * @return the comments
	 * @see #comments
	 */
	public List<Pair<String, String>> getComments() {
		return comments;
	}

	/**
	 * @param comments
	 *          the comments to set
	 * @see #comments
	 */
	public void setComments(List<Pair<String, String>> comments) {
		this.comments = comments;
	}

	/**
	 * @return the type
	 * @see #type
	 */
	public Class<?> getType() {
		return type;
	}

	/**
	 * @param type
	 *          the type to set
	 * @see #type
	 */
	public void setType(Class<?> type) {
		this.type = type;
	}

}
