package lcsb.mapviewer.services.search.layout;

import java.util.Map;

import lcsb.mapviewer.model.map.species.Element;
import lcsb.mapviewer.services.search.ElementView;

/**
 * Light {@link ElementView view} for alias representing data that should be
 * send to client about alias related to
 * {@link lcsb.mapviewer.model.map.layout.Layout}.
 * 
 * @author Piotr Gawron
 *
 */
public class LightLayoutAliasView extends ElementView {

	/**
	 * 
	 */
	private static final long		serialVersionUID = 1L;

	/**
	 * Value used to highlight {@link Element} in a a layout.
	 */
	private Double							value;

	/**
	 * Color used to highlight {@link Element} in a layout.
	 */
	private Map<String, Object>	color;

	/**
	 * Default constructor.
	 * 
	 * @param alias
	 *          original object from which this on is created
	 */
	protected LightLayoutAliasView(Element alias) {
		super(alias.getId(), alias.getModel().getId());
	}

	/**
	 * Constructor that should be used only for (de)serialization.
	 */
	protected LightLayoutAliasView() {
		super();
	}

	/**
	 * @return the value
	 * @see #value
	 */
	public Double getValue() {
		return value;
	}

	/**
	 * @param value
	 *          the value to set
	 * @see #value
	 */
	public void setValue(Double value) {
		this.value = value;
	}

	/**
	 * @return the color
	 * @see #color
	 */
	public Map<String, Object> getColor() {
		return color;
	}

	/**
	 * @param color
	 *          the color to set
	 * @see #color
	 */
	public void setColor(Map<String, Object> color) {
		this.color = color;
	}

	@Override
	public String toString() {
		return "[" + this.getClass().getSimpleName() + "] " + //
				"alias_id: " + getIdObject() + ", " + //
				"value: " + getValue() + ", " + //
				"color: " + getColor() + ", ";

	}

}
