package lcsb.mapviewer.services.view;

import lcsb.mapviewer.model.map.OverviewImage;

import org.apache.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;

import lcsb.mapviewer.common.exception.NotImplementedException;

import com.google.gson.Gson;

/**
 * Factory class for {@link OverviewImage} class.
 * 
 * @author Piotr Gawron
 * 
 */
@Transactional(value = "txManager")
public class OverviewImageViewFactory extends AbstractViewFactory<OverviewImage, OverviewImageView> {
	/**
	 * Default class logger.
	 */
	private static Logger						logger	= Logger.getLogger(OverviewImageViewFactory.class);

	/**
	 * Factory object used for creation of {@link OverviewImageView} elements.
	 */
	@Autowired
	private OverviewLinkViewFactory	overviewLinkViewFactory;

	@Override
	public OverviewImageView create(OverviewImage object) {
		OverviewImageView result = new OverviewImageView(object);
		if (object == null) {
			logger.warn("Empty image...");
			return result;
		}
		if (object.getProject() != null) {
			result.setFilename(object.getProject().getDirectory() + "/" + object.getFilename());
		} else {
			result.setFilename(object.getFilename());
		}
		result.setWidth(object.getWidth());
		result.setHeight(object.getHeight());
		result.setLinks(overviewLinkViewFactory.createList(object.getLinks()));

		return result;
	}

	@Override
	public String createGson(OverviewImageView object) {
		return new Gson().toJson(object);
	}

	@Override
	public OverviewImage viewToObject(OverviewImageView view) {
		throw new NotImplementedException();
	}
}
