package lcsb.mapviewer.services.view;

import lcsb.mapviewer.model.user.BasicPrivilege;
import lcsb.mapviewer.model.user.ObjectPrivilege;
import lcsb.mapviewer.model.user.PrivilegeType;

import org.apache.log4j.Logger;

import lcsb.mapviewer.common.exception.NotImplementedException;

import com.google.gson.Gson;

/**
 * Factory class for {@link PrivilegeView} class.
 * 
 * @author Piotr Gawron
 * 
 */
public class PrivilegeViewFactory extends AbstractViewFactory<BasicPrivilege, PrivilegeView> {
	/**
	 * Default class logger.
	 */
	private static Logger	logger	= Logger.getLogger(PrivilegeViewFactory.class);

	@Override
	public PrivilegeView create(BasicPrivilege privilege) {
		PrivilegeView result = new PrivilegeView(privilege);
		if (privilege == null) {
			return result;
		}
		result.setSelected(privilege.getLevel() > 0);
		result.setType(privilege.getType());
		if (privilege.getType() != null) {
			result.setCommonName(privilege.getType().getCommonName());
			result.setNumeric(privilege.getType().isNumeric());
		} else {
			logger.warn("Privilege without type...");
		}
		if (privilege.getClass().equals(ObjectPrivilege.class)) {
			result.setObjectId(((ObjectPrivilege) privilege).getId());
		}
		result.setLevel(privilege.getLevel());
		return result;
	}

	/**
	 * Creates empty {@link PrivilegeView} element for given {@link PrivilegeType}
	 * .
	 * 
	 * 
	 * @param type
	 *          type of empty privilege to create
	 * @return empty {@link PrivilegeView} element for given {@link PrivilegeType}
	 * 
	 */
	public PrivilegeView create(PrivilegeType type) {
		return new PrivilegeView(type);
	}

	@Override
	public String createGson(PrivilegeView object) {
		return new Gson().toJson(object);
	}

	@Override
	public BasicPrivilege viewToObject(PrivilegeView view) {
		throw new NotImplementedException();
	}
}
