package lcsb.mapviewer.services.impl;

import static org.junit.Assert.assertFalse;

import java.io.FileInputStream;
import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

import org.apache.commons.io.IOUtils;
import org.apache.log4j.Logger;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.test.annotation.Rollback;

import lcsb.mapviewer.common.IProgressUpdater;
import lcsb.mapviewer.model.Project;
import lcsb.mapviewer.model.map.MiriamData;
import lcsb.mapviewer.model.map.MiriamType;
import lcsb.mapviewer.model.map.graph.DataMining;
import lcsb.mapviewer.model.map.graph.DataMiningSet;
import lcsb.mapviewer.model.map.model.Model;
import lcsb.mapviewer.model.map.species.Element;
import lcsb.mapviewer.model.map.species.GenericProtein;
import lcsb.mapviewer.model.map.species.Protein;
import lcsb.mapviewer.services.ServiceTestFunctions;
import lcsb.mapviewer.services.interfaces.IDataMiningService;

@Rollback(true)
public class DataMiningServiceTest extends ServiceTestFunctions {
	static Logger			 logger	= Logger.getLogger(DataMiningServiceTest.class);

	private Model			 model;
	private Project		 project;

	@Autowired
	IDataMiningService dm;

	@Before
	public void setUp() throws Exception {
		model = getModelForFile("testFiles/graph_path_example3.xml", false);
		project = new Project();
		project.addModel(model);
		projectDao.add(project);
		modelDao.add(model);

		createUser();
	}

	@After
	public void tearDown() throws Exception {
		modelDao.delete(model);
		projectDao.delete(project);
		userDao.delete(user);
	}

	@Test
	public void testDuplicateMiriamInParseData() throws Exception {
		try {
			DataMiningSet dm = new DataMiningSet();
			dm.setInputData(IOUtils.toByteArray(new FileInputStream("testFiles/data_mining/sample_input.txt")));
			Set<Element> set = new HashSet<>();
			Protein p1 = new GenericProtein("id1");
			p1.addMiriamData(new MiriamData(MiriamType.HGNC_SYMBOL, "SNCA"));
			Protein p2 = new GenericProtein("id2");
			p2.addMiriamData(new MiriamData(MiriamType.HGNC_SYMBOL, "SNCA"));
			set.add(p1);
			set.add(p2);

			Set<DataMining> result = dataMiningService.parseData(dm, set, new HashSet<>(), new IProgressUpdater() {
				@Override
				public void setProgress(double progress) {
				}
			});

			List<MiriamData> list = new ArrayList<>();
			for (DataMining dataMining : result) {
				list.addAll(dataMining.getReferences());
			}
			for (int i = 0; i < list.size(); i++) {
				for (int j = i + 1; j < list.size(); j++) {
					assertFalse("Duplicates of miriam objects found", list.get(i) == list.get(j));
				}
			}

		} catch (Exception e) {
			e.printStackTrace();
			throw e;
		}

	}

}
